@@ -1,15 +1,15 @@
 # Copyright (c) 2004, 2005 Anders Ard
 
-## $Id: Config.pm,v 1.9 2006/11/08 11:13:59 anders Exp $
+## $Id: Config.pm 296 2008-11-16 17:30:04Z it-aar $
 # 
 # See the file LICENCE included in the distribution.
 
 package Combine::Config;
 
 use strict;
-use Config::General;
+use Config::General qw(SaveConfigString);
 
-our $VERSION = '3.4';
+our $VERSION = '3.12-0';
 our %serverbypreferred = ();
 our %serverbyalias     = ();
 our @allow = ();
