@@ -9,7 +9,7 @@ use MIME::Base64;
 
 my $level=0; #Used to calculate indentation for pretty printing
 
-my %dcMap;
+our %dcMap;
    %dcMap = (
             'rights' => 'dc:rights',
             'coverage' => 'dc:coverage',
@@ -37,11 +37,12 @@ my %dcMap;
             'documenttype' => 'dc:type',
             'doc-rights' => 'dc:rights',
             'page-topic' => 'dc:subject',
+            'topicname' => 'dc:subject',
             'keyword' => 'dc:subject',
             'document-rights' => 'dc:rights',
             'keywords' => 'dc:subject',
             'resource-type' => 'dc:type',
-            'summary' => 'dc:description ',
+            'summary' => 'dc:description',
             'creation-date' => 'dc:date',
             'type' => 'dc:type',
             'document-classification' => 'dc:subject',
@@ -53,17 +54,17 @@ my %dcMap;
             'created' => 'dc:date',
             'timemodified' => 'dc:date',
             'doc-type' => 'dc:type',
-            'mimetype' => 'dc:type '
+            'mimetype' => 'dc:type'
             );
 
 ##########################SUBS########################
 
 sub XWI2XML {
-    my ($xwi, $inclHTML, $inclCanonDoc) = @_;
+    my ($xwi, $inclHTML, $inclCanonDoc, $collapseinLinks, $nooutLinks) = @_;
     my $recordid=$xwi->recordid;
     my $Rsummary = '';
     my $md5 = $xwi->md5;
-    my $res = StartTag("documentRecord id=\"$md5\"");
+    my $res = StartTag("documentRecord md5id=\"$md5\" id=\"$recordid\"");
 
     $res .= ToXML('modifiedDate', time2iso($xwi->modifiedDate));
     $res .= ToXML('expiryDate', time2iso($xwi->expiryDate));
@@ -119,6 +120,14 @@ sub XWI2XML {
     $res .= StartTag('metaData');
     my $tit= $xwi->title;
     $res .= ToXMLAttr('meta',"name=\"title\"", $tit);
+    if ( !defined($tit) || $tit =~ /^\s*$/ ) {
+      #Empty title => generate title from text and 1st heading
+      my @ip = split(/\s+/,substr(${$xwi->text},0,100),5);
+      my ($head,$t) = split(/;/, $xwi->heading_get, 2);
+      my $ip = join(' ', $ip[0], $ip[1], $ip[2], $ip[3]);
+      if ( $ip =~ /$head/ ) { $res .= ToXMLAttr('meta',"name=\"title\"", $ip); }
+      else  { $res .= ToXMLAttr('meta',"name=\"title\"", $head . ' ' . $ip); }
+    }
     my ($name,$content);
     while (1) {
 	($name,$content) = $xwi->meta_get;
@@ -131,7 +140,7 @@ sub XWI2XML {
         $name = encodeXML($name);
 
           if (($name =~ /^dc\./)) {
-            $name =~ s/^dc\./dc:/;
+            $name =~ s/^dc\.\s*/dc:/;
             my $t;
             ($name,$t) = split('\.', $name, 2);
             if ($name =~ /subject/) { $res .= DCsubj($name,$content); }
@@ -153,7 +162,8 @@ sub XWI2XML {
     $sth = $sv->prepare(qq{SELECT urlstr FROM urls WHERE urls.urlid=?;});
     my $sth1 = $sv->prepare(qq{SELECT md5 FROM recordurl WHERE urlid=?;});
     my %seen = ();
-    while (1) {
+#    while (1) {
+    while (!$nooutLinks) {
 	($urlstr, $netlocid, $urlid, $anchor, $ltype) = $xwi->link_get;
 	last unless ($urlstr || $netlocid);
 	if ( $urlstr eq '' ) {
@@ -189,9 +199,11 @@ sub XWI2XML {
 	$res .= StartTag('inlinks');
 	while (($from,$anchor,$lmd5,$ltype)=$sth->fetchrow_array) {
             $anchor = Encode::decode('utf8',$anchor);
-
-                next if ( defined($seen{$from,$anchor}) || ($anchor eq '') );
+                next if ( defined($seen{$from,$anchor}) || ($anchor eq '') || defined($seen{$anchor}) );
                 $seen{$from,$anchor}=1;
+                if ($collapseinLinks) {
+                  $seen{$anchor}=1;
+                }
                 my $s = $from;
                 $s =~ s|http://([^/:]+).*|$1|;
                 if (defined($servers{$s})) {#from same server as page, just save and put last in list
