@@ -14,6 +14,8 @@ USE $database;
 #TABLE html: recordid^, html
 #TABLE analys: recordid*, name, value
 #TABLE topic: recordid*, notation*, absscore, relscore, terms, algorithm
+#TABLE localtags: netlocid, urlid, name, value
+#TABLE search: recordid^, stext*
 #
 #(TABLE netlocalias: netlocid*, netlocstr^)
 #(TABLE urlalias: urlid*, urlstr^)
@@ -29,7 +31,6 @@ USE $database;
 #TABLE robotrules: netlocid*, rule, expire
 #TABLE oai: recordid, md5^, date*, status
 #TABLE exports: host, port, last
-#TABLE localtags: netlocid, urlid, name, value
 
 #Data tables
 CREATE TABLE hdb (
@@ -92,6 +93,21 @@ CREATE TABLE topic (
   KEY recordid (recordid)
 ) ENGINE=MyISAM DEFAULT CHARACTER SET=utf8;
 
+CREATE TABLE localtags (
+  netlocid int(11) NOT NULL DEFAULT '0',
+  urlid int(11) NOT NULL DEFAULT '0',
+  name varchar(100) NOT NULL,
+  value varchar(100) NOT NULL,
+  PRIMARY KEY tag (netlocid,urlid,name(100),value(100))
+) ENGINE=MyISAM DEFAULT CHARACTER SET=utf8;
+
+CREATE TABLE search (
+  recordid int(11) NOT NULL default '0',
+  stext mediumtext,
+  PRIMARY KEY (recordid),
+  FULLTEXT (stext)
+) ENGINE=MyISAM AVG_ROW_LENGTH = 20000 MAX_ROWS = 10000000 DEFAULT CHARACTER SET=utf8;
+
 
 #Administrative tables
 CREATE TABLE netlocalias (
@@ -212,14 +228,6 @@ CREATE TABLE exports (
   last timestamp DEFAULT '1999-12-31'
 ) ENGINE=MyISAM DEFAULT CHARACTER SET=utf8;
 
-CREATE TABLE localtags (
-  netlocid int(11) NOT NULL DEFAULT '0',
-  urlid int(11) NOT NULL DEFAULT '0',
-  name varchar(100) NOT NULL,
-  value varchar(100) NOT NULL,
-  PRIMARY KEY tag (netlocid,urlid,name(100),value(100))
-) ENGINE=MyISAM DEFAULT CHARACTER SET=utf8;
-
 
 #Create user dbuser with required priviligies
 GRANT SELECT,INSERT,UPDATE,DELETE,CREATE,CREATE TEMPORARY TABLES,
